# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_data_in.models.designer_transfers_adp_auth_params_dto import DesignerTransfersAdpAuthParamsDTO
from visier_api_data_in.models.designer_transfers_bamboo_auth_params_dto import DesignerTransfersBambooAuthParamsDTO
from visier_api_data_in.models.designer_transfers_basic_s3_auth_params_dto import DesignerTransfersBasicS3AuthParamsDTO
from visier_api_data_in.models.designer_transfers_big_query_auth_params_dto import DesignerTransfersBigQueryAuthParamsDTO
from visier_api_data_in.models.designer_transfers_copy_s3_auth_params_dto import DesignerTransfersCopyS3AuthParamsDTO
from visier_api_data_in.models.designer_transfers_dayforce_v2_auth_params_dto import DesignerTransfersDayforceV2AuthParamsDTO
from visier_api_data_in.models.designer_transfers_dimensions_auth_params_dto import DesignerTransfersDimensionsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_fusion_auth_params_dto import DesignerTransfersFusionAuthParamsDTO
from visier_api_data_in.models.designer_transfers_gong_auth_params_dto import DesignerTransfersGongAuthParamsDTO
from visier_api_data_in.models.designer_transfers_google_sheets_auth_params_dto import DesignerTransfersGoogleSheetsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_google_workspace_auth_params_dto import DesignerTransfersGoogleWorkspaceAuthParamsDTO
from visier_api_data_in.models.designer_transfers_greenhouse_auth_params_dto import DesignerTransfersGreenhouseAuthParamsDTO
from visier_api_data_in.models.designer_transfers_icims_auth_params_dto import DesignerTransfersIcimsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_internal_s3_auth_params_dto import DesignerTransfersInternalS3AuthParamsDTO
from visier_api_data_in.models.designer_transfers_jdbc_auth_params_dto import DesignerTransfersJdbcAuthParamsDTO
from visier_api_data_in.models.designer_transfers_jira_auth_params_dto import DesignerTransfersJiraAuthParamsDTO
from visier_api_data_in.models.designer_transfers_lever_auth_params_dto import DesignerTransfersLeverAuthParamsDTO
from visier_api_data_in.models.designer_transfers_medallia_auth_params_dto import DesignerTransfersMedalliaAuthParamsDTO
from visier_api_data_in.models.designer_transfers_microsoft365_auth_params_dto import DesignerTransfersMicrosoft365AuthParamsDTO
from visier_api_data_in.models.designer_transfers_my_sql_auth_params_dto import DesignerTransfersMySqlAuthParamsDTO
from visier_api_data_in.models.designer_transfers_namely_auth_params_dto import DesignerTransfersNamelyAuthParamsDTO
from visier_api_data_in.models.designer_transfers_oracle_db_auth_params_dto import DesignerTransfersOracleDbAuthParamsDTO
from visier_api_data_in.models.designer_transfers_qualtrics_auth_params_dto import DesignerTransfersQualtricsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_redshift_auth_params_dto import DesignerTransfersRedshiftAuthParamsDTO
from visier_api_data_in.models.designer_transfers_salesforce_auth_params_dto import DesignerTransfersSalesforceAuthParamsDTO
from visier_api_data_in.models.designer_transfers_salesforce_v2_auth_params_dto import DesignerTransfersSalesforceV2AuthParamsDTO
from visier_api_data_in.models.designer_transfers_service_now_auth_params_dto import DesignerTransfersServiceNowAuthParamsDTO
from visier_api_data_in.models.designer_transfers_service_now_v2_auth_params_dto import DesignerTransfersServiceNowV2AuthParamsDTO
from visier_api_data_in.models.designer_transfers_slack_auth_params_dto import DesignerTransfersSlackAuthParamsDTO
from visier_api_data_in.models.designer_transfers_snowflake_auth_params_dto import DesignerTransfersSnowflakeAuthParamsDTO
from visier_api_data_in.models.designer_transfers_sql_server_auth_params_dto import DesignerTransfersSqlServerAuthParamsDTO
from visier_api_data_in.models.designer_transfers_success_factors_auth_params_dto import DesignerTransfersSuccessFactorsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_ultimate_auth_params_dto import DesignerTransfersUltimateAuthParamsDTO
from visier_api_data_in.models.designer_transfers_willow_auth_params_dto import DesignerTransfersWillowAuthParamsDTO
from visier_api_data_in.models.designer_transfers_workday_auth_params_dto import DesignerTransfersWorkdayAuthParamsDTO
from visier_api_data_in.models.designer_transfers_workday_raas_auth_params_dto import DesignerTransfersWorkdayRaasAuthParamsDTO
from visier_api_data_in.models.designer_transfers_zoom_auth_params_dto import DesignerTransfersZoomAuthParamsDTO
from typing import Optional, Set
from typing_extensions import Self

class DesignerTransfersDataProviderAuthParamsDTO(BaseModel):
    """
    DesignerTransfersDataProviderAuthParamsDTO
    """ # noqa: E501
    adp_auth_params: Optional[DesignerTransfersAdpAuthParamsDTO] = Field(default=None, alias="adpAuthParams")
    auth_context: Optional[StrictStr] = Field(default=None, alias="authContext")
    bamboo_auth_params: Optional[DesignerTransfersBambooAuthParamsDTO] = Field(default=None, alias="bambooAuthParams")
    big_query_auth_params: Optional[DesignerTransfersBigQueryAuthParamsDTO] = Field(default=None, alias="bigQueryAuthParams")
    copy_s3_auth_params: Optional[DesignerTransfersCopyS3AuthParamsDTO] = Field(default=None, alias="copyS3AuthParams")
    dayforce_v2_auth_params: Optional[DesignerTransfersDayforceV2AuthParamsDTO] = Field(default=None, alias="dayforceV2AuthParams")
    dimensions_auth_params: Optional[DesignerTransfersDimensionsAuthParamsDTO] = Field(default=None, alias="dimensionsAuthParams")
    empty_auth_params: Optional[Dict[str, Any]] = Field(default=None, alias="emptyAuthParams")
    fusion_auth_params: Optional[DesignerTransfersFusionAuthParamsDTO] = Field(default=None, alias="fusionAuthParams")
    gong_auth_params: Optional[DesignerTransfersGongAuthParamsDTO] = Field(default=None, alias="gongAuthParams")
    google_sheets_auth_params: Optional[DesignerTransfersGoogleSheetsAuthParamsDTO] = Field(default=None, alias="googleSheetsAuthParams")
    google_workspace_auth_params: Optional[DesignerTransfersGoogleWorkspaceAuthParamsDTO] = Field(default=None, alias="googleWorkspaceAuthParams")
    greenhouse_auth_params: Optional[DesignerTransfersGreenhouseAuthParamsDTO] = Field(default=None, alias="greenhouseAuthParams")
    has_updates: Optional[StrictBool] = Field(default=None, alias="hasUpdates")
    icims_auth_params: Optional[DesignerTransfersIcimsAuthParamsDTO] = Field(default=None, alias="icimsAuthParams")
    internal_s3_auth_params: Optional[DesignerTransfersInternalS3AuthParamsDTO] = Field(default=None, alias="internalS3AuthParams")
    jdbc_auth_params: Optional[DesignerTransfersJdbcAuthParamsDTO] = Field(default=None, alias="jdbcAuthParams")
    jira_auth_params: Optional[DesignerTransfersJiraAuthParamsDTO] = Field(default=None, alias="jiraAuthParams")
    lever_auth_params: Optional[DesignerTransfersLeverAuthParamsDTO] = Field(default=None, alias="leverAuthParams")
    medallia_auth_params: Optional[DesignerTransfersMedalliaAuthParamsDTO] = Field(default=None, alias="medalliaAuthParams")
    ms365_auth_params: Optional[DesignerTransfersMicrosoft365AuthParamsDTO] = Field(default=None, alias="ms365AuthParams")
    my_sql_auth_params: Optional[DesignerTransfersMySqlAuthParamsDTO] = Field(default=None, alias="mySqlAuthParams")
    namely_auth_params: Optional[DesignerTransfersNamelyAuthParamsDTO] = Field(default=None, alias="namelyAuthParams")
    oracle_db_auth_params: Optional[DesignerTransfersOracleDbAuthParamsDTO] = Field(default=None, alias="oracleDbAuthParams")
    provider: Optional[StrictStr] = Field(default=None, description="The data provider associated with the credential.")
    qualtrics_auth_params: Optional[DesignerTransfersQualtricsAuthParamsDTO] = Field(default=None, alias="qualtricsAuthParams")
    redshift_auth_params: Optional[DesignerTransfersRedshiftAuthParamsDTO] = Field(default=None, alias="redshiftAuthParams")
    s3_auth_params: Optional[DesignerTransfersBasicS3AuthParamsDTO] = Field(default=None, alias="s3AuthParams")
    salesforce_auth_params: Optional[DesignerTransfersSalesforceAuthParamsDTO] = Field(default=None, alias="salesforceAuthParams")
    salesforce_v2_auth_params: Optional[DesignerTransfersSalesforceV2AuthParamsDTO] = Field(default=None, alias="salesforceV2AuthParams")
    service_now_auth_params: Optional[DesignerTransfersServiceNowAuthParamsDTO] = Field(default=None, alias="serviceNowAuthParams")
    service_now_v2_auth_params: Optional[DesignerTransfersServiceNowV2AuthParamsDTO] = Field(default=None, alias="serviceNowV2AuthParams")
    slack_auth_params: Optional[DesignerTransfersSlackAuthParamsDTO] = Field(default=None, alias="slackAuthParams")
    snowflake_auth_params: Optional[DesignerTransfersSnowflakeAuthParamsDTO] = Field(default=None, alias="snowflakeAuthParams")
    sql_server_auth_params: Optional[DesignerTransfersSqlServerAuthParamsDTO] = Field(default=None, alias="sqlServerAuthParams")
    success_factors_auth_params: Optional[DesignerTransfersSuccessFactorsAuthParamsDTO] = Field(default=None, alias="successFactorsAuthParams")
    tenant_domain_name: Optional[StrictStr] = Field(default=None, alias="tenantDomainName")
    ultimate_auth_params: Optional[DesignerTransfersUltimateAuthParamsDTO] = Field(default=None, alias="ultimateAuthParams")
    willow_auth_params: Optional[DesignerTransfersWillowAuthParamsDTO] = Field(default=None, alias="willowAuthParams")
    workday_auth_params: Optional[DesignerTransfersWorkdayAuthParamsDTO] = Field(default=None, alias="workdayAuthParams")
    workday_raas_auth_params: Optional[DesignerTransfersWorkdayRaasAuthParamsDTO] = Field(default=None, alias="workdayRaasAuthParams")
    zoom_auth_params: Optional[DesignerTransfersZoomAuthParamsDTO] = Field(default=None, alias="zoomAuthParams")
    __properties: ClassVar[List[str]] = ["adpAuthParams", "authContext", "bambooAuthParams", "bigQueryAuthParams", "copyS3AuthParams", "dayforceV2AuthParams", "dimensionsAuthParams", "emptyAuthParams", "fusionAuthParams", "gongAuthParams", "googleSheetsAuthParams", "googleWorkspaceAuthParams", "greenhouseAuthParams", "hasUpdates", "icimsAuthParams", "internalS3AuthParams", "jdbcAuthParams", "jiraAuthParams", "leverAuthParams", "medalliaAuthParams", "ms365AuthParams", "mySqlAuthParams", "namelyAuthParams", "oracleDbAuthParams", "provider", "qualtricsAuthParams", "redshiftAuthParams", "s3AuthParams", "salesforceAuthParams", "salesforceV2AuthParams", "serviceNowAuthParams", "serviceNowV2AuthParams", "slackAuthParams", "snowflakeAuthParams", "sqlServerAuthParams", "successFactorsAuthParams", "tenantDomainName", "ultimateAuthParams", "willowAuthParams", "workdayAuthParams", "workdayRaasAuthParams", "zoomAuthParams"]

    @field_validator('auth_context')
    def auth_context_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DefaultDataExtraction', 'WorkplaceDynamicsDataExtraction', 'Notification']):
            raise ValueError("must be one of enum values ('DefaultDataExtraction', 'WorkplaceDynamicsDataExtraction', 'Notification')")
        return value

    @field_validator('provider')
    def provider_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Bamboo', 'GoogleSheets', 'Greenhouse', 'Jira', 'Lever', 'Namely', 'Qualtrics', 'Salesforce', 'UKG', 'Workday', 'Icims', 'ServiceNow', 'Jdbc', 'BasicS3', 'InternalS3', 'CopyS3', 'Redshift', 'Snowflake', 'BigQuery', 'SqlServer', 'Dimensions', 'IcimsPartnerProviderRedshift', 'Willow', 'SuccessFactors', 'IcimsV2', 'ADP', 'WorkdayV2', 'ServiceNowV2', 'Medallia', 'Fusion', 'SalesforceV2', 'Gong', 'Zoom', 'GoogleCalendar', 'UKGV2', 'DayforceV2', 'GoogleActivityReport', 'Slack', 'MySql', 'WorkdayRaas', 'Microsoft365', 'GoogleWorkspace', 'OracleDb', 'SmartRecruiters', 'WorkdayWQL', 'OEMCornerstone']):
            raise ValueError("must be one of enum values ('Bamboo', 'GoogleSheets', 'Greenhouse', 'Jira', 'Lever', 'Namely', 'Qualtrics', 'Salesforce', 'UKG', 'Workday', 'Icims', 'ServiceNow', 'Jdbc', 'BasicS3', 'InternalS3', 'CopyS3', 'Redshift', 'Snowflake', 'BigQuery', 'SqlServer', 'Dimensions', 'IcimsPartnerProviderRedshift', 'Willow', 'SuccessFactors', 'IcimsV2', 'ADP', 'WorkdayV2', 'ServiceNowV2', 'Medallia', 'Fusion', 'SalesforceV2', 'Gong', 'Zoom', 'GoogleCalendar', 'UKGV2', 'DayforceV2', 'GoogleActivityReport', 'Slack', 'MySql', 'WorkdayRaas', 'Microsoft365', 'GoogleWorkspace', 'OracleDb', 'SmartRecruiters', 'WorkdayWQL', 'OEMCornerstone')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DesignerTransfersDataProviderAuthParamsDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of adp_auth_params
        if self.adp_auth_params:
            _dict['adpAuthParams'] = self.adp_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bamboo_auth_params
        if self.bamboo_auth_params:
            _dict['bambooAuthParams'] = self.bamboo_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of big_query_auth_params
        if self.big_query_auth_params:
            _dict['bigQueryAuthParams'] = self.big_query_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of copy_s3_auth_params
        if self.copy_s3_auth_params:
            _dict['copyS3AuthParams'] = self.copy_s3_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dayforce_v2_auth_params
        if self.dayforce_v2_auth_params:
            _dict['dayforceV2AuthParams'] = self.dayforce_v2_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dimensions_auth_params
        if self.dimensions_auth_params:
            _dict['dimensionsAuthParams'] = self.dimensions_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fusion_auth_params
        if self.fusion_auth_params:
            _dict['fusionAuthParams'] = self.fusion_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gong_auth_params
        if self.gong_auth_params:
            _dict['gongAuthParams'] = self.gong_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of google_sheets_auth_params
        if self.google_sheets_auth_params:
            _dict['googleSheetsAuthParams'] = self.google_sheets_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of google_workspace_auth_params
        if self.google_workspace_auth_params:
            _dict['googleWorkspaceAuthParams'] = self.google_workspace_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of greenhouse_auth_params
        if self.greenhouse_auth_params:
            _dict['greenhouseAuthParams'] = self.greenhouse_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of icims_auth_params
        if self.icims_auth_params:
            _dict['icimsAuthParams'] = self.icims_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of internal_s3_auth_params
        if self.internal_s3_auth_params:
            _dict['internalS3AuthParams'] = self.internal_s3_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jdbc_auth_params
        if self.jdbc_auth_params:
            _dict['jdbcAuthParams'] = self.jdbc_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jira_auth_params
        if self.jira_auth_params:
            _dict['jiraAuthParams'] = self.jira_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of lever_auth_params
        if self.lever_auth_params:
            _dict['leverAuthParams'] = self.lever_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of medallia_auth_params
        if self.medallia_auth_params:
            _dict['medalliaAuthParams'] = self.medallia_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ms365_auth_params
        if self.ms365_auth_params:
            _dict['ms365AuthParams'] = self.ms365_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of my_sql_auth_params
        if self.my_sql_auth_params:
            _dict['mySqlAuthParams'] = self.my_sql_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of namely_auth_params
        if self.namely_auth_params:
            _dict['namelyAuthParams'] = self.namely_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of oracle_db_auth_params
        if self.oracle_db_auth_params:
            _dict['oracleDbAuthParams'] = self.oracle_db_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of qualtrics_auth_params
        if self.qualtrics_auth_params:
            _dict['qualtricsAuthParams'] = self.qualtrics_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of redshift_auth_params
        if self.redshift_auth_params:
            _dict['redshiftAuthParams'] = self.redshift_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of s3_auth_params
        if self.s3_auth_params:
            _dict['s3AuthParams'] = self.s3_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of salesforce_auth_params
        if self.salesforce_auth_params:
            _dict['salesforceAuthParams'] = self.salesforce_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of salesforce_v2_auth_params
        if self.salesforce_v2_auth_params:
            _dict['salesforceV2AuthParams'] = self.salesforce_v2_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of service_now_auth_params
        if self.service_now_auth_params:
            _dict['serviceNowAuthParams'] = self.service_now_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of service_now_v2_auth_params
        if self.service_now_v2_auth_params:
            _dict['serviceNowV2AuthParams'] = self.service_now_v2_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of slack_auth_params
        if self.slack_auth_params:
            _dict['slackAuthParams'] = self.slack_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of snowflake_auth_params
        if self.snowflake_auth_params:
            _dict['snowflakeAuthParams'] = self.snowflake_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sql_server_auth_params
        if self.sql_server_auth_params:
            _dict['sqlServerAuthParams'] = self.sql_server_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of success_factors_auth_params
        if self.success_factors_auth_params:
            _dict['successFactorsAuthParams'] = self.success_factors_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ultimate_auth_params
        if self.ultimate_auth_params:
            _dict['ultimateAuthParams'] = self.ultimate_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of willow_auth_params
        if self.willow_auth_params:
            _dict['willowAuthParams'] = self.willow_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workday_auth_params
        if self.workday_auth_params:
            _dict['workdayAuthParams'] = self.workday_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workday_raas_auth_params
        if self.workday_raas_auth_params:
            _dict['workdayRaasAuthParams'] = self.workday_raas_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of zoom_auth_params
        if self.zoom_auth_params:
            _dict['zoomAuthParams'] = self.zoom_auth_params.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DesignerTransfersDataProviderAuthParamsDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "adpAuthParams": DesignerTransfersAdpAuthParamsDTO.from_dict(obj["adpAuthParams"]) if obj.get("adpAuthParams") is not None else None,
            "authContext": obj.get("authContext"),
            "bambooAuthParams": DesignerTransfersBambooAuthParamsDTO.from_dict(obj["bambooAuthParams"]) if obj.get("bambooAuthParams") is not None else None,
            "bigQueryAuthParams": DesignerTransfersBigQueryAuthParamsDTO.from_dict(obj["bigQueryAuthParams"]) if obj.get("bigQueryAuthParams") is not None else None,
            "copyS3AuthParams": DesignerTransfersCopyS3AuthParamsDTO.from_dict(obj["copyS3AuthParams"]) if obj.get("copyS3AuthParams") is not None else None,
            "dayforceV2AuthParams": DesignerTransfersDayforceV2AuthParamsDTO.from_dict(obj["dayforceV2AuthParams"]) if obj.get("dayforceV2AuthParams") is not None else None,
            "dimensionsAuthParams": DesignerTransfersDimensionsAuthParamsDTO.from_dict(obj["dimensionsAuthParams"]) if obj.get("dimensionsAuthParams") is not None else None,
            "emptyAuthParams": obj.get("emptyAuthParams"),
            "fusionAuthParams": DesignerTransfersFusionAuthParamsDTO.from_dict(obj["fusionAuthParams"]) if obj.get("fusionAuthParams") is not None else None,
            "gongAuthParams": DesignerTransfersGongAuthParamsDTO.from_dict(obj["gongAuthParams"]) if obj.get("gongAuthParams") is not None else None,
            "googleSheetsAuthParams": DesignerTransfersGoogleSheetsAuthParamsDTO.from_dict(obj["googleSheetsAuthParams"]) if obj.get("googleSheetsAuthParams") is not None else None,
            "googleWorkspaceAuthParams": DesignerTransfersGoogleWorkspaceAuthParamsDTO.from_dict(obj["googleWorkspaceAuthParams"]) if obj.get("googleWorkspaceAuthParams") is not None else None,
            "greenhouseAuthParams": DesignerTransfersGreenhouseAuthParamsDTO.from_dict(obj["greenhouseAuthParams"]) if obj.get("greenhouseAuthParams") is not None else None,
            "hasUpdates": obj.get("hasUpdates"),
            "icimsAuthParams": DesignerTransfersIcimsAuthParamsDTO.from_dict(obj["icimsAuthParams"]) if obj.get("icimsAuthParams") is not None else None,
            "internalS3AuthParams": DesignerTransfersInternalS3AuthParamsDTO.from_dict(obj["internalS3AuthParams"]) if obj.get("internalS3AuthParams") is not None else None,
            "jdbcAuthParams": DesignerTransfersJdbcAuthParamsDTO.from_dict(obj["jdbcAuthParams"]) if obj.get("jdbcAuthParams") is not None else None,
            "jiraAuthParams": DesignerTransfersJiraAuthParamsDTO.from_dict(obj["jiraAuthParams"]) if obj.get("jiraAuthParams") is not None else None,
            "leverAuthParams": DesignerTransfersLeverAuthParamsDTO.from_dict(obj["leverAuthParams"]) if obj.get("leverAuthParams") is not None else None,
            "medalliaAuthParams": DesignerTransfersMedalliaAuthParamsDTO.from_dict(obj["medalliaAuthParams"]) if obj.get("medalliaAuthParams") is not None else None,
            "ms365AuthParams": DesignerTransfersMicrosoft365AuthParamsDTO.from_dict(obj["ms365AuthParams"]) if obj.get("ms365AuthParams") is not None else None,
            "mySqlAuthParams": DesignerTransfersMySqlAuthParamsDTO.from_dict(obj["mySqlAuthParams"]) if obj.get("mySqlAuthParams") is not None else None,
            "namelyAuthParams": DesignerTransfersNamelyAuthParamsDTO.from_dict(obj["namelyAuthParams"]) if obj.get("namelyAuthParams") is not None else None,
            "oracleDbAuthParams": DesignerTransfersOracleDbAuthParamsDTO.from_dict(obj["oracleDbAuthParams"]) if obj.get("oracleDbAuthParams") is not None else None,
            "provider": obj.get("provider"),
            "qualtricsAuthParams": DesignerTransfersQualtricsAuthParamsDTO.from_dict(obj["qualtricsAuthParams"]) if obj.get("qualtricsAuthParams") is not None else None,
            "redshiftAuthParams": DesignerTransfersRedshiftAuthParamsDTO.from_dict(obj["redshiftAuthParams"]) if obj.get("redshiftAuthParams") is not None else None,
            "s3AuthParams": DesignerTransfersBasicS3AuthParamsDTO.from_dict(obj["s3AuthParams"]) if obj.get("s3AuthParams") is not None else None,
            "salesforceAuthParams": DesignerTransfersSalesforceAuthParamsDTO.from_dict(obj["salesforceAuthParams"]) if obj.get("salesforceAuthParams") is not None else None,
            "salesforceV2AuthParams": DesignerTransfersSalesforceV2AuthParamsDTO.from_dict(obj["salesforceV2AuthParams"]) if obj.get("salesforceV2AuthParams") is not None else None,
            "serviceNowAuthParams": DesignerTransfersServiceNowAuthParamsDTO.from_dict(obj["serviceNowAuthParams"]) if obj.get("serviceNowAuthParams") is not None else None,
            "serviceNowV2AuthParams": DesignerTransfersServiceNowV2AuthParamsDTO.from_dict(obj["serviceNowV2AuthParams"]) if obj.get("serviceNowV2AuthParams") is not None else None,
            "slackAuthParams": DesignerTransfersSlackAuthParamsDTO.from_dict(obj["slackAuthParams"]) if obj.get("slackAuthParams") is not None else None,
            "snowflakeAuthParams": DesignerTransfersSnowflakeAuthParamsDTO.from_dict(obj["snowflakeAuthParams"]) if obj.get("snowflakeAuthParams") is not None else None,
            "sqlServerAuthParams": DesignerTransfersSqlServerAuthParamsDTO.from_dict(obj["sqlServerAuthParams"]) if obj.get("sqlServerAuthParams") is not None else None,
            "successFactorsAuthParams": DesignerTransfersSuccessFactorsAuthParamsDTO.from_dict(obj["successFactorsAuthParams"]) if obj.get("successFactorsAuthParams") is not None else None,
            "tenantDomainName": obj.get("tenantDomainName"),
            "ultimateAuthParams": DesignerTransfersUltimateAuthParamsDTO.from_dict(obj["ultimateAuthParams"]) if obj.get("ultimateAuthParams") is not None else None,
            "willowAuthParams": DesignerTransfersWillowAuthParamsDTO.from_dict(obj["willowAuthParams"]) if obj.get("willowAuthParams") is not None else None,
            "workdayAuthParams": DesignerTransfersWorkdayAuthParamsDTO.from_dict(obj["workdayAuthParams"]) if obj.get("workdayAuthParams") is not None else None,
            "workdayRaasAuthParams": DesignerTransfersWorkdayRaasAuthParamsDTO.from_dict(obj["workdayRaasAuthParams"]) if obj.get("workdayRaasAuthParams") is not None else None,
            "zoomAuthParams": DesignerTransfersZoomAuthParamsDTO.from_dict(obj["zoomAuthParams"]) if obj.get("zoomAuthParams") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_data_in.models
from visier_api_data_in.models.designer_transfers_data_provider_auth_information_dto import DesignerTransfersDataProviderAuthInformationDTO

class TestDesignerTransfersDataProviderAuthInformationDTO(unittest.TestCase):
    """DesignerTransfersDataProviderAuthInformationDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DesignerTransfersDataProviderAuthInformationDTO:
        """Test DesignerTransfersDataProviderAuthInformationDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return DesignerTransfersDataProviderAuthInformationDTO(
                data_provider_auth_params = visier_api_data_in.models.designer/transfers/data_provider_auth_params_dto.designer.transfers.DataProviderAuthParamsDTO(
                    adp_auth_params = visier_api_data_in.models.designer/transfers/adp_auth_params_dto.designer.transfers.AdpAuthParamsDTO(
                        auth_code = '', ), 
                    auth_context = 'DefaultDataExtraction', 
                    bamboo_auth_params = visier_api_data_in.models.designer/transfers/bamboo_auth_params_dto.designer.transfers.BambooAuthParamsDTO(
                        access_key = '', 
                        tenant_domain_name = '', ), 
                    big_query_auth_params = visier_api_data_in.models.designer/transfers/big_query_auth_params_dto.designer.transfers.BigQueryAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        dataset_location = '', 
                        default_dataset = '', 
                        project_id = '', 
                        refresh_token = '', 
                        service_account_params = visier_api_data_in.models.designer/transfers/big_query_service_account_params_dto.designer.transfers.BigQueryServiceAccountParamsDTO(
                            private_key = '', 
                            service_account_email = '', ), ), 
                    copy_s3_auth_params = visier_api_data_in.models.designer/transfers/copy_s3_auth_params_dto.designer.transfers.CopyS3AuthParamsDTO(
                        iam_role = '', ), 
                    dayforce_v2_auth_params = visier_api_data_in.models.designer/transfers/dayforce_v2_auth_params_dto.designer.transfers.DayforceV2AuthParamsDTO(
                        company_id = '', 
                        host_domain_name = '', 
                        password = '', 
                        token_host = '', 
                        username = '', ), 
                    dimensions_auth_params = visier_api_data_in.models.designer/transfers/dimensions_auth_params_dto.designer.transfers.DimensionsAuthParamsDTO(
                        app_key = '', 
                        client_id = '', 
                        client_secret = '', 
                        password = '', 
                        username = '', 
                        vanity_url = '', ), 
                    empty_auth_params = visier_api_data_in.models.designer/transfers/empty_auth_params_dto.designer.transfers.EmptyAuthParamsDTO(), 
                    fusion_auth_params = visier_api_data_in.models.designer/transfers/fusion_auth_params_dto.designer.transfers.FusionAuthParamsDTO(
                        host_domain_name = '', 
                        password = '', 
                        username = '', ), 
                    gong_auth_params = visier_api_data_in.models.designer/transfers/gong_auth_params_dto.designer.transfers.GongAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', ), 
                    google_sheets_auth_params = visier_api_data_in.models.designer/transfers/google_sheets_auth_params_dto.designer.transfers.GoogleSheetsAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        configuration = '', ), 
                    google_workspace_auth_params = visier_api_data_in.models.designer/transfers/google_workspace_auth_params_dto.designer.transfers.GoogleWorkspaceAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        privacy_mode = '', 
                        service_account = '', ), 
                    greenhouse_auth_params = visier_api_data_in.models.designer/transfers/greenhouse_auth_params_dto.designer.transfers.GreenhouseAuthParamsDTO(
                        api_key = '', ), 
                    has_updates = True, 
                    icims_auth_params = visier_api_data_in.models.designer/transfers/icims_auth_params_dto.designer.transfers.IcimsAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        customer_id = '', 
                        password = '', 
                        region = 'US', 
                        username = '', ), 
                    internal_s3_auth_params = visier_api_data_in.models.designer/transfers/internal_s3_auth_params_dto.designer.transfers.InternalS3AuthParamsDTO(
                        bucket_name = '', 
                        path = '', ), 
                    jdbc_auth_params = visier_api_data_in.models.designer/transfers/jdbc_auth_params_dto.designer.transfers.JdbcAuthParamsDTO(
                        jdbc_connect_string = '', 
                        password = '', 
                        username = '', ), 
                    jira_auth_params = visier_api_data_in.models.designer/transfers/jira_auth_params_dto.designer.transfers.JiraAuthParamsDTO(
                        api_token = '', 
                        connect_params = visier_api_data_in.models.designer/transfers/jira_connect_params_dto.designer.transfers.JiraConnectParamsDTO(
                            app_key = '', 
                            client_key = '', 
                            shared_secret = '', ), 
                        host_name = '', ), 
                    lever_auth_params = visier_api_data_in.models.designer/transfers/lever_auth_params_dto.designer.transfers.LeverAuthParamsDTO(
                        api_key = '', ), 
                    medallia_auth_params = visier_api_data_in.models.designer/transfers/medallia_auth_params_dto.designer.transfers.MedalliaAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        instance_url = '', 
                        tenant_domain_name = '', ), 
                    ms365_auth_params = visier_api_data_in.models.designer/transfers/microsoft365_auth_params_dto.designer.transfers.Microsoft365AuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        o_auth_tenant_id = '', 
                        privacy_mode = '', ), 
                    my_sql_auth_params = visier_api_data_in.models.designer/transfers/my_sql_auth_params_dto.designer.transfers.MySqlAuthParamsDTO(
                        database = '', 
                        host = '', 
                        password = '', 
                        port = '', 
                        ssl_mode = '', 
                        username = '', ), 
                    namely_auth_params = visier_api_data_in.models.designer/transfers/namely_auth_params_dto.designer.transfers.NamelyAuthParamsDTO(
                        auth_code = '', ), 
                    oracle_db_auth_params = visier_api_data_in.models.designer/transfers/oracle_db_auth_params_dto.designer.transfers.OracleDbAuthParamsDTO(
                        host = '', 
                        password = '', 
                        port = '', 
                        service_name = '', 
                        username = '', ), 
                    provider = 'Bamboo', 
                    qualtrics_auth_params = visier_api_data_in.models.designer/transfers/qualtrics_auth_params_dto.designer.transfers.QualtricsAuthParamsDTO(
                        api_token = '', 
                        data_center_id = '', ), 
                    redshift_auth_params = visier_api_data_in.models.designer/transfers/redshift_auth_params_dto.designer.transfers.RedshiftAuthParamsDTO(
                        database = '', 
                        endpoint = '', 
                        password = '', 
                        port = '', 
                        schema = '', 
                        table_prefix = '', 
                        username = '', ), 
                    s3_auth_params = visier_api_data_in.models.designer/transfers/basic_s3_auth_params_dto.designer.transfers.BasicS3AuthParamsDTO(
                        access_key = '', 
                        bucket_name = '', 
                        bucket_region = '', 
                        path = '', 
                        secret_key = '', ), 
                    salesforce_auth_params = visier_api_data_in.models.designer/transfers/salesforce_auth_params_dto.designer.transfers.SalesforceAuthParamsDTO(
                        client_id = '', 
                        refresh_token = '', ), 
                    salesforce_v2_auth_params = visier_api_data_in.models.designer/transfers/salesforce_v2_auth_params_dto.designer.transfers.SalesforceV2AuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        login_host = '', ), 
                    service_now_auth_params = visier_api_data_in.models.designer/transfers/service_now_auth_params_dto.designer.transfers.ServiceNowAuthParamsDTO(
                        host_domain_name = '', 
                        password = '', 
                        username = '', ), 
                    service_now_v2_auth_params = visier_api_data_in.models.designer/transfers/service_now_v2_auth_params_dto.designer.transfers.ServiceNowV2AuthParamsDTO(
                        alternate_domain = '', 
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        host_domain_name = '', ), 
                    slack_auth_params = visier_api_data_in.models.designer/transfers/slack_auth_params_dto.designer.transfers.SlackAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', ), 
                    snowflake_auth_params = visier_api_data_in.models.designer/transfers/snowflake_auth_params_dto.designer.transfers.SnowflakeAuthParamsDTO(
                        account_identifier = '', 
                        database = '', 
                        password = '', 
                        private_key = '', 
                        schema = '', 
                        username = '', 
                        warehouse = '', ), 
                    sql_server_auth_params = visier_api_data_in.models.designer/transfers/sql_server_auth_params_dto.designer.transfers.SqlServerAuthParamsDTO(
                        database = '', 
                        host = '', 
                        password = '', 
                        port = '', 
                        username = '', ), 
                    success_factors_auth_params = visier_api_data_in.models.designer/transfers/success_factors_auth_params_dto.designer.transfers.SuccessFactorsAuthParamsDTO(
                        company_id = '', 
                        host_domain_name = '', 
                        o_auth = visier_api_data_in.models.designer/transfers/success_factors_o_auth_params_dto.designer.transfers.SuccessFactorsOAuthParamsDTO(
                            api_key = '', 
                            private_x509_key = '', 
                            public_x509_cert = '', ), 
                        password = '', 
                        username = '', ), 
                    tenant_domain_name = '', 
                    ultimate_auth_params = visier_api_data_in.models.designer/transfers/ultimate_auth_params_dto.designer.transfers.UltimateAuthParamsDTO(
                        api_key = '', 
                        host_domain_name = '', 
                        password = '', 
                        user_access_key = '', 
                        username = '', ), 
                    willow_auth_params = visier_api_data_in.models.designer/transfers/willow_auth_params_dto.designer.transfers.WillowAuthParamsDTO(
                        api_token = '', 
                        host_name = '', ), 
                    workday_auth_params = visier_api_data_in.models.designer/transfers/workday_auth_params_dto.designer.transfers.WorkdayAuthParamsDTO(
                        api_key = '', 
                        domain_name = '', 
                        implementation_name = '', 
                        integration_system_id = '', 
                        password = '', 
                        ref_token = visier_api_data_in.models.designer/transfers/workday_refresh_token_params_dto.designer.transfers.WorkdayRefreshTokenParamsDTO(
                            api_client_id = '', 
                            client_secret = '', 
                            refresh_token = '', ), 
                        user_id = '', ), 
                    workday_raas_auth_params = visier_api_data_in.models.designer/transfers/workday_raas_auth_params_dto.designer.transfers.WorkdayRaasAuthParamsDTO(
                        domain_name = '', 
                        implementation_name = '', 
                        password = '', 
                        test_report_url = '', 
                        user_id = '', ), 
                    zoom_auth_params = visier_api_data_in.models.designer/transfers/zoom_auth_params_dto.designer.transfers.ZoomAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', ), ),
                data_provider_basic_information = visier_api_data_in.models.designer/transfers/data_provider_basic_information_dto.designer.transfers.DataProviderBasicInformationDTO(
                    description = '', 
                    display_name = '', ),
                data_provider_metadata = visier_api_data_in.models.designer/transfers/data_provider_basic_metadata_dto.designer.transfers.DataProviderBasicMetadataDTO(
                    can_children_inherit = True, )
            )
        else:
            return DesignerTransfersDataProviderAuthInformationDTO(
        )

    def testDesignerTransfersDataProviderAuthInformationDTO(self):
        """Test DesignerTransfersDataProviderAuthInformationDTO"""
        def validate_instance(instance):
            DesignerTransfersDataProviderAuthInformationDTO.model_validate(inst_req_only)
            instance_deserialized = DesignerTransfersDataProviderAuthInformationDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


__version__ = "0.99201.1793"

# import apis into sdk package
from visier_api_data_in.api.data_and_job_handling_api import DataAndJobHandlingApi
from visier_api_data_in.api.data_intake_api import DataIntakeApi
from visier_api_data_in.api.data_upload_api import DataUploadApi
from visier_api_data_in.api.direct_data_intake_api import DirectDataIntakeApi
from visier_api_data_in.api.pgp_key_api import PGPKeyApi
from visier_api_data_in.api.planning_data_load_api import PlanningDataLoadApi


# import models into sdk package
from visier_api_data_in.models.admin_data_transfers_import_definition_apidto import AdminDataTransfersImportDefinitionAPIDTO
from visier_api_data_in.models.admin_data_transfers_import_definitions_apidto import AdminDataTransfersImportDefinitionsAPIDTO
from visier_api_data_in.models.admin_jobs_consolidated_analytics_job_request_dto import AdminJobsConsolidatedAnalyticsJobRequestDTO
from visier_api_data_in.models.admin_jobs_extract_data_and_load_dto import AdminJobsExtractDataAndLoadDTO
from visier_api_data_in.models.admin_jobs_processing_job_request_dto import AdminJobsProcessingJobRequestDTO
from visier_api_data_in.models.admin_transfers_assign_connector_credentials_by_tenant_response_dto import AdminTransfersAssignConnectorCredentialsByTenantResponseDTO
from visier_api_data_in.models.admin_transfers_assign_connector_credentials_response_dto import AdminTransfersAssignConnectorCredentialsResponseDTO
from visier_api_data_in.models.admin_transfers_assign_connector_with_credentials_response_dto import AdminTransfersAssignConnectorWithCredentialsResponseDTO
from visier_api_data_in.models.admin_transfers_assigned_credential_info_response_dto import AdminTransfersAssignedCredentialInfoResponseDTO
from visier_api_data_in.models.admin_transfers_connector_info_response_dto import AdminTransfersConnectorInfoResponseDTO
from visier_api_data_in.models.admin_transfers_connector_setting_request_dto import AdminTransfersConnectorSettingRequestDTO
from visier_api_data_in.models.admin_transfers_connector_setting_response_dto import AdminTransfersConnectorSettingResponseDTO
from visier_api_data_in.models.admin_transfers_connector_settings_response_dto import AdminTransfersConnectorSettingsResponseDTO
from visier_api_data_in.models.admin_transfers_data_version_and_date_dto import AdminTransfersDataVersionAndDateDTO
from visier_api_data_in.models.admin_transfers_extractor_setting_apidto import AdminTransfersExtractorSettingAPIDTO
from visier_api_data_in.models.admin_transfers_extractor_setting_key_value_apidto import AdminTransfersExtractorSettingKeyValueAPIDTO
from visier_api_data_in.models.admin_transfers_extractor_settings_apidto import AdminTransfersExtractorSettingsAPIDTO
from visier_api_data_in.models.admin_transfers_multiple_tenant_data_versions_details_dto import AdminTransfersMultipleTenantDataVersionsDetailsDTO
from visier_api_data_in.models.admin_transfers_multiple_tenant_data_versions_list_dto import AdminTransfersMultipleTenantDataVersionsListDTO
from visier_api_data_in.models.admin_transfers_set_connector_setting_request_dto import AdminTransfersSetConnectorSettingRequestDTO
from visier_api_data_in.models.admin_transfers_set_connector_setting_response_dto import AdminTransfersSetConnectorSettingResponseDTO
from visier_api_data_in.models.admin_transfers_set_connector_settings_request_dto import AdminTransfersSetConnectorSettingsRequestDTO
from visier_api_data_in.models.admin_transfers_set_connector_settings_response_dto import AdminTransfersSetConnectorSettingsResponseDTO
from visier_api_data_in.models.admin_transfers_tenant_connector_settings_request_dto import AdminTransfersTenantConnectorSettingsRequestDTO
from visier_api_data_in.models.data_in_assign_connector_credential_request import DataInAssignConnectorCredentialRequest
from visier_api_data_in.models.data_in_connector import DataInConnector
from visier_api_data_in.models.data_in_data_load_request import DataInDataLoadRequest
from visier_api_data_in.models.data_in_data_load_request_model import DataInDataLoadRequestModel
from visier_api_data_in.models.data_in_data_load_response import DataInDataLoadResponse
from visier_api_data_in.models.data_in_data_transfer_result_detail import DataInDataTransferResultDetail
from visier_api_data_in.models.data_in_data_version_object import DataInDataVersionObject
from visier_api_data_in.models.data_in_disable_dv_model import DataInDisableDVModel
from visier_api_data_in.models.data_in_disable_dv_request import DataInDisableDVRequest
from visier_api_data_in.models.data_in_disable_dv_response import DataInDisableDVResponse
from visier_api_data_in.models.data_in_dispatching_job_status_response import DataInDispatchingJobStatusResponse
from visier_api_data_in.models.data_in_exclude_data_uploads_request import DataInExcludeDataUploadsRequest
from visier_api_data_in.models.data_in_extraction_job import DataInExtractionJob
from visier_api_data_in.models.data_in_extraction_job_and_status_response import DataInExtractionJobAndStatusResponse
from visier_api_data_in.models.data_in_include_data_uploads_request import DataInIncludeDataUploadsRequest
from visier_api_data_in.models.data_in_job_status_list_response import DataInJobStatusListResponse
from visier_api_data_in.models.data_in_job_status_with_start_time import DataInJobStatusWithStartTime
from visier_api_data_in.models.data_in_processing_job import DataInProcessingJob
from visier_api_data_in.models.data_in_processing_job_and_status_response import DataInProcessingJobAndStatusResponse
from visier_api_data_in.models.data_in_processing_job_status_response import DataInProcessingJobStatusResponse
from visier_api_data_in.models.data_in_push_data_cancel_response import DataInPushDataCancelResponse
from visier_api_data_in.models.data_in_push_data_complete_request import DataInPushDataCompleteRequest
from visier_api_data_in.models.data_in_push_data_complete_response import DataInPushDataCompleteResponse
from visier_api_data_in.models.data_in_push_data_response import DataInPushDataResponse
from visier_api_data_in.models.data_in_receiving_job import DataInReceivingJob
from visier_api_data_in.models.data_in_receiving_job_and_status_response import DataInReceivingJobAndStatusResponse
from visier_api_data_in.models.data_in_receiving_job_status_response import DataInReceivingJobStatusResponse
from visier_api_data_in.models.data_in_result import DataInResult
from visier_api_data_in.models.data_in_source import DataInSource
from visier_api_data_in.models.data_in_start_extraction_response import DataInStartExtractionResponse
from visier_api_data_in.models.data_in_start_transfer_response import DataInStartTransferResponse
from visier_api_data_in.models.data_in_tenant import DataInTenant
from visier_api_data_in.models.data_in_tenant_and_credential import DataInTenantAndCredential
from visier_api_data_in.models.data_in_upload_to_exclude import DataInUploadToExclude
from visier_api_data_in.models.data_in_upload_to_include import DataInUploadToInclude
from visier_api_data_in.models.designer_crypto_key_pair_delete_response_dto import DesignerCryptoKeyPairDeleteResponseDTO
from visier_api_data_in.models.designer_crypto_key_pair_generate_request_dto import DesignerCryptoKeyPairGenerateRequestDTO
from visier_api_data_in.models.designer_crypto_public_key_dto import DesignerCryptoPublicKeyDTO
from visier_api_data_in.models.designer_crypto_public_keys_dto import DesignerCryptoPublicKeysDTO
from visier_api_data_in.models.designer_transfers_adp_auth_params_dto import DesignerTransfersAdpAuthParamsDTO
from visier_api_data_in.models.designer_transfers_bamboo_auth_params_dto import DesignerTransfersBambooAuthParamsDTO
from visier_api_data_in.models.designer_transfers_basic_s3_auth_params_dto import DesignerTransfersBasicS3AuthParamsDTO
from visier_api_data_in.models.designer_transfers_big_query_auth_params_dto import DesignerTransfersBigQueryAuthParamsDTO
from visier_api_data_in.models.designer_transfers_big_query_service_account_params_dto import DesignerTransfersBigQueryServiceAccountParamsDTO
from visier_api_data_in.models.designer_transfers_copy_s3_auth_params_dto import DesignerTransfersCopyS3AuthParamsDTO
from visier_api_data_in.models.designer_transfers_credential_creation_api_response_dto import DesignerTransfersCredentialCreationAPIResponseDTO
from visier_api_data_in.models.designer_transfers_data_provider_auth_information_dto import DesignerTransfersDataProviderAuthInformationDTO
from visier_api_data_in.models.designer_transfers_data_provider_auth_params_dto import DesignerTransfersDataProviderAuthParamsDTO
from visier_api_data_in.models.designer_transfers_data_provider_basic_information_dto import DesignerTransfersDataProviderBasicInformationDTO
from visier_api_data_in.models.designer_transfers_data_provider_basic_metadata_dto import DesignerTransfersDataProviderBasicMetadataDTO
from visier_api_data_in.models.designer_transfers_dayforce_v2_auth_params_dto import DesignerTransfersDayforceV2AuthParamsDTO
from visier_api_data_in.models.designer_transfers_dimensions_auth_params_dto import DesignerTransfersDimensionsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_extractor_credential_apidto import DesignerTransfersExtractorCredentialAPIDTO
from visier_api_data_in.models.designer_transfers_extractor_credentials_apidto import DesignerTransfersExtractorCredentialsAPIDTO
from visier_api_data_in.models.designer_transfers_fusion_auth_params_dto import DesignerTransfersFusionAuthParamsDTO
from visier_api_data_in.models.designer_transfers_gong_auth_params_dto import DesignerTransfersGongAuthParamsDTO
from visier_api_data_in.models.designer_transfers_google_sheets_auth_params_dto import DesignerTransfersGoogleSheetsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_google_workspace_auth_params_dto import DesignerTransfersGoogleWorkspaceAuthParamsDTO
from visier_api_data_in.models.designer_transfers_greenhouse_auth_params_dto import DesignerTransfersGreenhouseAuthParamsDTO
from visier_api_data_in.models.designer_transfers_icims_auth_params_dto import DesignerTransfersIcimsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_internal_s3_auth_params_dto import DesignerTransfersInternalS3AuthParamsDTO
from visier_api_data_in.models.designer_transfers_jdbc_auth_params_dto import DesignerTransfersJdbcAuthParamsDTO
from visier_api_data_in.models.designer_transfers_jira_auth_params_dto import DesignerTransfersJiraAuthParamsDTO
from visier_api_data_in.models.designer_transfers_jira_connect_params_dto import DesignerTransfersJiraConnectParamsDTO
from visier_api_data_in.models.designer_transfers_lever_auth_params_dto import DesignerTransfersLeverAuthParamsDTO
from visier_api_data_in.models.designer_transfers_medallia_auth_params_dto import DesignerTransfersMedalliaAuthParamsDTO
from visier_api_data_in.models.designer_transfers_microsoft365_auth_params_dto import DesignerTransfersMicrosoft365AuthParamsDTO
from visier_api_data_in.models.designer_transfers_my_sql_auth_params_dto import DesignerTransfersMySqlAuthParamsDTO
from visier_api_data_in.models.designer_transfers_namely_auth_params_dto import DesignerTransfersNamelyAuthParamsDTO
from visier_api_data_in.models.designer_transfers_oracle_db_auth_params_dto import DesignerTransfersOracleDbAuthParamsDTO
from visier_api_data_in.models.designer_transfers_push_data_column_definition_dto import DesignerTransfersPushDataColumnDefinitionDTO
from visier_api_data_in.models.designer_transfers_push_data_source_definition_dto import DesignerTransfersPushDataSourceDefinitionDTO
from visier_api_data_in.models.designer_transfers_push_data_source_definitions_dto import DesignerTransfersPushDataSourceDefinitionsDTO
from visier_api_data_in.models.designer_transfers_qualtrics_auth_params_dto import DesignerTransfersQualtricsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_redshift_auth_params_dto import DesignerTransfersRedshiftAuthParamsDTO
from visier_api_data_in.models.designer_transfers_salesforce_auth_params_dto import DesignerTransfersSalesforceAuthParamsDTO
from visier_api_data_in.models.designer_transfers_salesforce_v2_auth_params_dto import DesignerTransfersSalesforceV2AuthParamsDTO
from visier_api_data_in.models.designer_transfers_service_now_auth_params_dto import DesignerTransfersServiceNowAuthParamsDTO
from visier_api_data_in.models.designer_transfers_service_now_v2_auth_params_dto import DesignerTransfersServiceNowV2AuthParamsDTO
from visier_api_data_in.models.designer_transfers_slack_auth_params_dto import DesignerTransfersSlackAuthParamsDTO
from visier_api_data_in.models.designer_transfers_snowflake_auth_params_dto import DesignerTransfersSnowflakeAuthParamsDTO
from visier_api_data_in.models.designer_transfers_sql_server_auth_params_dto import DesignerTransfersSqlServerAuthParamsDTO
from visier_api_data_in.models.designer_transfers_subject_missing_access_dto import DesignerTransfersSubjectMissingAccessDTO
from visier_api_data_in.models.designer_transfers_success_factors_auth_params_dto import DesignerTransfersSuccessFactorsAuthParamsDTO
from visier_api_data_in.models.designer_transfers_success_factors_o_auth_params_dto import DesignerTransfersSuccessFactorsOAuthParamsDTO
from visier_api_data_in.models.designer_transfers_ultimate_auth_params_dto import DesignerTransfersUltimateAuthParamsDTO
from visier_api_data_in.models.designer_transfers_willow_auth_params_dto import DesignerTransfersWillowAuthParamsDTO
from visier_api_data_in.models.designer_transfers_workday_auth_params_dto import DesignerTransfersWorkdayAuthParamsDTO
from visier_api_data_in.models.designer_transfers_workday_o_auth_params_dto import DesignerTransfersWorkdayOAuthParamsDTO
from visier_api_data_in.models.designer_transfers_workday_raas_auth_params_dto import DesignerTransfersWorkdayRaasAuthParamsDTO
from visier_api_data_in.models.designer_transfers_workday_refresh_token_params_dto import DesignerTransfersWorkdayRefreshTokenParamsDTO
from visier_api_data_in.models.designer_transfers_zoom_auth_params_dto import DesignerTransfersZoomAuthParamsDTO
from visier_api_data_in.models.direct_data_upload_file_response_dto import DirectDataUploadFileResponseDTO
from visier_api_data_in.models.dp_transfers_cancel_job_batch_from_job_id_dto import DpTransfersCancelJobBatchFromJobIdDTO
from visier_api_data_in.models.dp_transfers_job_cancellation_result_dto import DpTransfersJobCancellationResultDTO
from visier_api_data_in.models.dp_transfers_job_cancellation_results_dto import DpTransfersJobCancellationResultsDTO
from visier_api_data_in.models.plan_data_load_change_dto import PlanDataLoadChangeDTO
from visier_api_data_in.models.plan_data_load_change_list_dto import PlanDataLoadChangeListDTO
from visier_api_data_in.models.plan_data_upload_response_dto import PlanDataUploadResponseDTO
from visier_api_data_in.models.plan_row_data_load_response_dto import PlanRowDataLoadResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_data_categories_response_dto import ServicingPublicapiTransfersDataCategoriesResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_data_category_response_dto import ServicingPublicapiTransfersDataCategoryResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_job_config_dto import ServicingPublicapiTransfersDirectDataJobConfigDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_job_status_response_dto import ServicingPublicapiTransfersDirectDataJobStatusResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_load_config_dto import ServicingPublicapiTransfersDirectDataLoadConfigDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_schema_dto import ServicingPublicapiTransfersDirectDataSchemaDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_schema_field_dto import ServicingPublicapiTransfersDirectDataSchemaFieldDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_transaction_start_response_dto import ServicingPublicapiTransfersDirectDataTransactionStartResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_direct_data_upload_file_response_dto import ServicingPublicapiTransfersDirectDataUploadFileResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_job_id_response import ServicingPublicapiTransfersJobIdResponse
from visier_api_data_in.models.servicing_publicapi_transfers_tenant_data_upload_status_response_dto import ServicingPublicapiTransfersTenantDataUploadStatusResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_tenant_data_upload_update_status_response_dto import ServicingPublicapiTransfersTenantDataUploadUpdateStatusResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_tenant_data_uploads_list_response_dto import ServicingPublicapiTransfersTenantDataUploadsListResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_tenant_data_uploads_response_dto import ServicingPublicapiTransfersTenantDataUploadsResponseDTO
from visier_api_data_in.models.servicing_publicapi_transfers_tenant_data_uploads_update_response_dto import ServicingPublicapiTransfersTenantDataUploadsUpdateResponseDTO
from visier_api_data_in.models.status import Status



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_data_in.models.admin_transfers_multiple_tenant_data_versions_details_dto import AdminTransfersMultipleTenantDataVersionsDetailsDTO
from typing import Optional, Set
from typing_extensions import Self

class AdminTransfersMultipleTenantDataVersionsListDTO(BaseModel):
    """
    AdminTransfersMultipleTenantDataVersionsListDTO
    """ # noqa: E501
    limit: Optional[StrictInt] = Field(default=None, description="The number of analytic tenants to retrieve. The maximum number to retrieve is 1000.")
    start: Optional[StrictInt] = Field(default=None, description="The index to start retrieving results from, also known as offset. The index begins at 0.")
    tenants: Optional[List[AdminTransfersMultipleTenantDataVersionsDetailsDTO]] = Field(default=None, description="A list of analytic tenants and their latest enabled data versions.")
    __properties: ClassVar[List[str]] = ["limit", "start", "tenants"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AdminTransfersMultipleTenantDataVersionsListDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tenants (list)
        _items = []
        if self.tenants:
            for _item_tenants in self.tenants:
                if _item_tenants:
                    _items.append(_item_tenants.to_dict())
            _dict['tenants'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AdminTransfersMultipleTenantDataVersionsListDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "limit": obj.get("limit"),
            "start": obj.get("start"),
            "tenants": [AdminTransfersMultipleTenantDataVersionsDetailsDTO.from_dict(_item) for _item in obj["tenants"]] if obj.get("tenants") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AdminJobsExtractDataAndLoadDTO(BaseModel):
    """
    AdminJobsExtractDataAndLoadDTO
    """ # noqa: E501
    all_tenants: Optional[StrictBool] = Field(default=None, description="If `true`, one extraction job is dispatched for each accessible analytic tenant. Only valid for requests from an administrating tenant.", alias="allTenants")
    batch_size_override: Optional[StrictInt] = Field(default=None, description="The maximum number of subjects the job can retrieve in each batch.", alias="batchSizeOverride")
    connector_ids: Optional[List[StrictStr]] = Field(default=None, description="The unique identifiers of the connectors to run extraction jobs.", alias="connectorIds")
    data_category_id: Optional[StrictStr] = Field(default=None, description="The unique identifier of the data category on which to trigger the extraction job. Default is the tenant's primary data category.", alias="dataCategoryId")
    disable_artifact_generation: Optional[StrictBool] = Field(default=None, description="If `true`, the job does not generate data load artifacts. If unspecified, the default is `false`.", alias="disableArtifactGeneration")
    excluded_tenants: Optional[List[StrictStr]] = Field(default=None, description="The unique identifiers of the tenants to exclude from the extraction job. Only valid if `allTenants` is `true`. Only valid for requests from an administrating tenant.", alias="excludedTenants")
    extract_to_time_override: Optional[StrictStr] = Field(default=None, description="An epoch timestamp in milliseconds for the end time up to which to retrieve data.", alias="extractToTimeOverride")
    force_update_existing_artifacts: Optional[StrictBool] = Field(default=None, description="If `true` and `disableArtifactGeneration` is `false`, updates extractor artifacts, which may overwrite the artifacts' manual overrides. Ignored if `disableArtifactGeneration` is `true`.", alias="forceUpdateExistingArtifacts")
    last_extraction_time_offset_mode: Optional[StrictStr] = Field(default=None, description="The mode used to offset the last extraction time (weeks vs months)", alias="lastExtractionTimeOffsetMode")
    last_extraction_time_offset_months: Optional[StrictInt] = Field(default=None, description="The number of months to offset the last extraction time. This overrides the last extraction date backward to retrieve more data.", alias="lastExtractionTimeOffsetMonths")
    last_extraction_time_offset_weeks: Optional[StrictInt] = Field(default=None, description="The number of weeks in the past to retrieve data. This overrides the last extraction date to retrieve more data.", alias="lastExtractionTimeOffsetWeeks")
    months_to_extract: Optional[StrictInt] = Field(default=None, description="The number of months to retrieve snapshot data.", alias="monthsToExtract")
    offset_month_option: Optional[StrictStr] = Field(default=None, description="The month options used to offset the last extraction time (first of month / last of month)", alias="offsetMonthOption")
    offset_week_option: Optional[StrictStr] = Field(default=None, description="The week options used to offset the last extraction time (first of day / last of day)", alias="offsetWeekOption")
    override_last_extraction_timestamp: Optional[StrictStr] = Field(default=None, description="An epoch timestamp in milliseconds from which to retrieve data. This overrides the last extraction date to retrieve more data.", alias="overrideLastExtractionTimestamp")
    publish_data_load_artifacts: Optional[StrictBool] = Field(default=None, description="If `true`, the generated data load artifacts are published to production immediately.", alias="publishDataLoadArtifacts")
    run_processing_job: Optional[StrictBool] = Field(default=None, description="If `true`, a processing job is spawned after a dispatched extraction job runs successfully.", alias="runProcessingJob")
    spill_debug_info_detail_level_dto: Optional[StrictStr] = Field(default=None, description="The detail level of the debugging info to be generated. Valid values are:  - `fileAndLine`: Debugging info is generated for file and line.  - `mappingName`: Debugging info is generated for mapping name.", alias="spillDebugInfoDetailLevelDTO")
    spill_debug_info_partitions_dto: Optional[StrictStr] = Field(default=None, description="The partitioning of debugging info to be generated, if any. Valid values are:  - `spillNone`: No debugging info is generated.  - `spillStagesAndRecords`: Debugging info is generated for stages and records.  - `spillAll`: Debugging info is generated for all partitions.", alias="spillDebugInfoPartitionsDTO")
    sql_batch_size: Optional[StrictInt] = Field(default=None, description="The maximum number of SQL table records the job can retrieve in each batch.", alias="sqlBatchSize")
    tenants: Optional[List[StrictStr]] = Field(default=None, description="A list of analytic tenants to dispatch extraction jobs for. One extraction job is dispatched per tenant. Only valid for requests from an administrating tenant.")
    __properties: ClassVar[List[str]] = ["allTenants", "batchSizeOverride", "connectorIds", "dataCategoryId", "disableArtifactGeneration", "excludedTenants", "extractToTimeOverride", "forceUpdateExistingArtifacts", "lastExtractionTimeOffsetMode", "lastExtractionTimeOffsetMonths", "lastExtractionTimeOffsetWeeks", "monthsToExtract", "offsetMonthOption", "offsetWeekOption", "overrideLastExtractionTimestamp", "publishDataLoadArtifacts", "runProcessingJob", "spillDebugInfoDetailLevelDTO", "spillDebugInfoPartitionsDTO", "sqlBatchSize", "tenants"]

    @field_validator('spill_debug_info_detail_level_dto')
    def spill_debug_info_detail_level_dto_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fileAndLine', 'mappingName']):
            raise ValueError("must be one of enum values ('fileAndLine', 'mappingName')")
        return value

    @field_validator('spill_debug_info_partitions_dto')
    def spill_debug_info_partitions_dto_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['spillNone', 'spillStagesAndRecords', 'spillAll']):
            raise ValueError("must be one of enum values ('spillNone', 'spillStagesAndRecords', 'spillAll')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AdminJobsExtractDataAndLoadDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AdminJobsExtractDataAndLoadDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allTenants": obj.get("allTenants"),
            "batchSizeOverride": obj.get("batchSizeOverride"),
            "connectorIds": obj.get("connectorIds"),
            "dataCategoryId": obj.get("dataCategoryId"),
            "disableArtifactGeneration": obj.get("disableArtifactGeneration"),
            "excludedTenants": obj.get("excludedTenants"),
            "extractToTimeOverride": obj.get("extractToTimeOverride"),
            "forceUpdateExistingArtifacts": obj.get("forceUpdateExistingArtifacts"),
            "lastExtractionTimeOffsetMode": obj.get("lastExtractionTimeOffsetMode"),
            "lastExtractionTimeOffsetMonths": obj.get("lastExtractionTimeOffsetMonths"),
            "lastExtractionTimeOffsetWeeks": obj.get("lastExtractionTimeOffsetWeeks"),
            "monthsToExtract": obj.get("monthsToExtract"),
            "offsetMonthOption": obj.get("offsetMonthOption"),
            "offsetWeekOption": obj.get("offsetWeekOption"),
            "overrideLastExtractionTimestamp": obj.get("overrideLastExtractionTimestamp"),
            "publishDataLoadArtifacts": obj.get("publishDataLoadArtifacts"),
            "runProcessingJob": obj.get("runProcessingJob"),
            "spillDebugInfoDetailLevelDTO": obj.get("spillDebugInfoDetailLevelDTO"),
            "spillDebugInfoPartitionsDTO": obj.get("spillDebugInfoPartitionsDTO"),
            "sqlBatchSize": obj.get("sqlBatchSize"),
            "tenants": obj.get("tenants")
        })
        return _obj


